==> haskell-annotated-wl-pprint-0.7.0-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-annotated-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: annotated-wl-pprint
version: 0.7.0
id: annotated-wl-pprint-0.7.0-8jpXgm4pnh36ZFEJZPnwUC
key: annotated-wl-pprint-0.7.0-8jpXgm4pnh36ZFEJZPnwUC
license: BSD3
maintainer: david@davidchristiansen.dk
homepage: https://github.com/david-christiansen/annotated-wl-pprint
synopsis: The Wadler/Leijen Pretty Printer, with annotation support
description:
    This is a modified version of wl-pprint, which was based on Wadler'\''s
    paper "A Prettier  Printer".  See the haddocks for full info.  This
    version allows the library user to annotate the text with semantic
    information, which can later be rendered in a variety of ways.
category: Text
author: Daan Leijen, David Raymond Christiansen
exposed: True
indefinite: False
exposed-modules:
    Text.PrettyPrint.Annotated.Leijen
abi: be3ec04ab27b9953a9314d128d889b08
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/annotated-wl-pprint-0.7.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/annotated-wl-pprint-0.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/annotated-wl-pprint-0.7.0
hs-libraries: HSannotated-wl-pprint-0.7.0-8jpXgm4pnh36ZFEJZPnwUC
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
haddock-interfaces: /usr/share/doc/haskell-annotated-wl-pprint/html/annotated-wl-pprint.haddock
haddock-html: /usr/share/doc/haskell-annotated-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-annotated-wl-pprint-0.7.0-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-annotated-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: annotated-wl-pprint
version: 0.7.0
id: annotated-wl-pprint-0.7.0-8APeXc1MGYdCeWTvpg0wB3
key: annotated-wl-pprint-0.7.0-8APeXc1MGYdCeWTvpg0wB3
license: BSD3
maintainer: david@davidchristiansen.dk
homepage: https://github.com/david-christiansen/annotated-wl-pprint
synopsis: The Wadler/Leijen Pretty Printer, with annotation support
description:
    This is a modified version of wl-pprint, which was based on Wadler'\''s
    paper "A Prettier  Printer".  See the haddocks for full info.  This
    version allows the library user to annotate the text with semantic
    information, which can later be rendered in a variety of ways.
category: Text
author: Daan Leijen, David Raymond Christiansen
exposed: True
indefinite: False
exposed-modules:
    Text.PrettyPrint.Annotated.Leijen
abi: 35fd3aae23b03330e6bc1f380b51de35
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/annotated-wl-pprint-0.7.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/annotated-wl-pprint-0.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/annotated-wl-pprint-0.7.0
hs-libraries: HSannotated-wl-pprint-0.7.0-8APeXc1MGYdCeWTvpg0wB3
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-annotated-wl-pprint/html/annotated-wl-pprint.haddock
haddock-html: /usr/share/doc/haskell-annotated-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
